@@ -3,8 +3,6 @@ map.world <- function(add = FALSE, main = "", ...)
     #
     # read in the map data
     #
-    data(rmp, package="sspline")
-    data(gwm, package="sspline")
     lon <- gwm[, 1]
     lat <- gwm[, 2]
 
